@@ -1,11 +1,13 @@
+# $Id: Cart.pm 504 2005-06-06 00:09:34Z claco $
 package Handel::Cart;
 use strict;
 use warnings;
 
 BEGIN {
     use base 'Handel::DBI';
-    use Handel::Constants qw(:cart);
+    use Handel::Constants qw(:cart :returnas);
     use Handel::Constraints qw(:all);
+    use Handel::Currency;
     use Handel::L10N qw(translate);
 };
 
@@ -93,23 +95,30 @@ sub items {
         translate('Param 1 is not a HASH reference') . '.') unless(
             ref($filter) eq 'HASH' or !$filter);
 
-    $filter ||= {};
+    $wantiterator ||= RETURNAS_AUTO;
+    $filter       ||= {};
 
     my $wildcard = Handel::DBI::has_wildcard($filter);
 
     ## If the filter as a wildcard, push it through a fresh search_like since it
     ## doesn't appear to be available within a loaded object.
-    if (wantarray) {
+    if ((wantarray && $wantiterator != RETURNAS_ITERATOR) || $wantiterator == RETURNAS_LIST) {
         my @items = $wildcard ?
             Handel::Cart::Item->search_like(%{$filter}, cart => $self->id) :
             $self->_items(%{$filter});
 
         return @items;
+    } elsif ($wantiterator == RETURNAS_ITERATOR) {
+        my $iterator = $wildcard ?
+            Handel::Cart::Item->search_like(%{$filter}, cart => $self->id) :
+            $self->_items(%{$filter});
+
+        return $iterator;
     } else {
         my $iterator = $wildcard ?
             Handel::Cart::Item->search_like(%{$filter}, cart => $self->id) :
             $self->_items(%{$filter});
-        if ($iterator->count == 1 and !$wantiterator) {
+        if ($iterator->count == 1 && $wantiterator != RETURNAS_ITERATOR && $wantiterator != RETURNAS_LIST) {
             return $iterator->next;
         } else {
             return $iterator;
@@ -124,15 +133,26 @@ sub load {
         translate('Param 1 is not a HASH reference') . '.') unless(
             ref($filter) eq 'HASH' or !$filter);
 
-    if (wantarray) {
+    $wantiterator ||= RETURNAS_AUTO;
+
+    ## only return array if wantarray and not explicitly asking for an iterator
+    ## or we've explicitly asked for a list/array
+    if ((wantarray && $wantiterator != RETURNAS_ITERATOR) || $wantiterator == RETURNAS_LIST) {
         my @carts = $filter ? $self->search_like(%{$filter}) :
             $self->retrieve_all;
         return @carts;
+    ## return an iterator if explicitly asked for
+    } elsif ($wantiterator == RETURNAS_ITERATOR) {
+        my $iterator = $filter ?
+            $self->search_like(%{$filter}) : $self->retrieve_all;
+
+        return $iterator;
+    ## full out auto
     } else {
         my $iterator = $filter ?
             $self->search_like(%{$filter}) : $self->retrieve_all;
 
-        if ($iterator->count == 1 && !$wantiterator) {
+        if ($iterator->count == 1 && $wantiterator != RETURNAS_ITERATOR && $wantiterator != RETURNAS_LIST) {
             return $iterator->next;
         } else {
             return $iterator;
@@ -209,7 +229,7 @@ sub subtotal {
         $subtotal += ( $item->total );
     };
 
-    return $subtotal;
+    return Handel::Currency->new($subtotal);
 };
 
 1;
@@ -219,10 +239,6 @@ __END__
 
 Handel::Cart - Module for maintaining shopping cart contents
 
-=head1 VERSION
-
-    $Id: Cart.pm 31 2004-12-31 02:11:44Z claco $
-
 =head1 SYNOPSIS
 
     use Handel::Cart;
@@ -247,12 +263,12 @@ Handel::Cart - Module for maintaining shopping cart contents
 
 =head1 DESCRIPTION
 
-C<Handel::Cart> is quick and dirty component for maintaing simple shopping cart
-data.
+C<Handel::Cart> is quick and dirty component for maintaining simple shopping
+cart data.
 
 While C<Handel::Cart> subclasses L<Class::DBI>, it is strongly recommended that
 you not use its methods unless it's absolutely necessary. Stick to the
-documented methods here and you'll be safe should I decide to impliment some
+documented methods here and you'll be safe should I decide to implement some
 other data access mechanism. :-)
 
 =head1 CONSTRUCTOR
@@ -284,13 +300,15 @@ You can also omit \%filter to load all available carts.
 In scalar context C<load> returns a C<Handel::Cart> object if there is a single
 result, or a L<Handel::Iterator> object if there are multiple results. You can
 force C<load> to always return an iterator even if only one cart exists by
-setting the C<$wantiterator> parameter to true.
+setting the C<$wantiterator> parameter to C<RETURNAS_ITERATOR>.
 
-    my $iterator = Handel::Cart->load(undef, 1);
+    my $iterator = Handel::Cart->load(undef, RETURNAS_ITERATOR);
     while (my $item = $iterator->next) {
         print $item->sku;
     };
 
+See L<Handel::Contstants> for the available C<RETURNAS> options.
+
 A C<Handel::Exception::Argument> exception is thrown if the first parameter is
 not a hashref.
 
@@ -360,9 +378,10 @@ When filtering the items in the shopping cart in scalar context, a
 C<Handel::Cart::Item> object will be returned if there is only one result. If
 there are multiple results, a Handel::Iterator object will be returned
 instead. You can force C<items> to always return a C<Handel::Iterator> object
-even if only one item exists by setting the $wantiterator parameter to true.
+even if only one item exists by setting the $wantiterator parameter to
+C<RETURNAS_ITERATOR>.
 
-    my $item = $cart->items({sku => 'SKU1234'});
+    my $item = $cart->items({sku => 'SKU1234'}, RETURNAS_ITERATOR);
     if ($item->isa('Handel::Cart::Item)) {
         print $item->sku;
     } else {
@@ -371,6 +390,8 @@ even if only one item exists by setting the $wantiterator parameter to true.
         };
     };
 
+See the C<RETURNAS> constants in L<Handel::Constants> for other options.
+
 In list context, filtered items return an array of items just as when items is
 called without a filter specified.
 
@@ -404,17 +425,18 @@ returns the number of items deleted.
 
 =head2 Saving Your Cart
 
-By default every shopping cart created is consided temporary (C<CART_TYPE_TEMP>)
-and could be deleted by cleanup processes at any time after the defined
-inactivity period. This could also be considered characteristic of whether the
-shopper id is from a temporary part of where it's used, or whether it is
-generated and stored within a customer profile assigned during authentication.
+By default every shopping cart created is considered temporary
+(C<CART_TYPE_TEMP>) and could be deleted by cleanup processes at any time after
+the defined inactivity period. This could also be considered characteristic of
+whether the shopper id is from a temporary part of where it's used, or whether
+it is generated and stored within a customer profile assigned during
+authentication.
 
 By saving your shopping cart, you are marking it as C<CART_TYPE_SAVED> and it
 should be left alone by any cleanup processes and available to that shopper at
 any time.
 
-For all intents and purposes, a saved cart is a wishlist. At some pointin the
+For all intents and purposes, a saved cart is a wishlist. At some point in the
 future they may be treated differently.
 
 =over
@@ -487,13 +509,17 @@ Returns/set the name of the current cart.
 =item C<$cart-E<gt>subtotal()>
 
 Returns the current total price of all the items in the cart object. This is
-equivilent to:
+equivalent to:
 
     my $iterator = $cart->items;
     while (my $item = $iterator->next) {
         $subtotal += $item->quantity*$item->price;
     };
 
+Starting in version C<0.12>, C<subtotal> now returns a stringified L<Handel::Currency>
+object. This can be used to format the price, and hopefully to convert it's currency
+to another locale in the future.
+
 =item C<$cart-E<gt>type()>
 
 Returns the type of the current cart. Currently the two types are
@@ -514,30 +540,13 @@ shopper at any time.
 
 =back
 
+=head1 SEE ALSO
+
+L<Handel::Constants>
+
 =head1 AUTHOR
 
     Christopher H. Laco
     CPAN ID: CLACO
-    cpan@chrislaco.com
+    claco@chrislaco.com
     http://today.icantfocus.com/blog/
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
