@@ -1,3 +1,4 @@
+# $Id: Item.pm 495 2005-05-30 01:38:24Z claco $
 package Handel::Cart::Item;
 use strict;
 use warnings;
@@ -5,18 +6,19 @@ use warnings;
 BEGIN {
     use base 'Handel::DBI';
     use Handel::Constraints qw(:all);
+    use Handel::Currency;
     use Handel::L10N qw(translate);
 };
 
 __PACKAGE__->table('cart_items');
-__PACKAGE__->autoupdate(0);
+__PACKAGE__->autoupdate(1);
 __PACKAGE__->iterator_class('Handel::Iterator');
-__PACKAGE__->columns( All => qw(id cart sku quantity price description) );
-__PACKAGE__->columns( Essential => qw(id cart sku quantity price description) );
-__PACKAGE__->add_constraint( 'quantity', quantity => \&constraint_quantity );
-__PACKAGE__->add_constraint( 'price',    price    => \&constraint_price );
-__PACKAGE__->add_constraint( 'id',       id       => \&constraint_uuid );
-__PACKAGE__->add_constraint( 'cart',     cart     => \&constraint_uuid );
+__PACKAGE__->columns(All => qw(id cart sku quantity price description));
+__PACKAGE__->columns(Essential => qw(id cart sku quantity price description));
+__PACKAGE__->add_constraint('quantity', quantity => \&constraint_quantity);
+__PACKAGE__->add_constraint('price',    price    => \&constraint_price);
+__PACKAGE__->add_constraint('id',       id       => \&constraint_uuid);
+__PACKAGE__->add_constraint('cart',     cart     => \&constraint_uuid);
 
 sub new {
     my ($self, $data) = @_;
@@ -32,9 +34,20 @@ sub new {
     return $self->construct($data);
 };
 
+sub price {
+    my ($self, $price) = @_;
+
+    if (defined $price) {
+        $self->_price($price);
+        return undef;
+    } else {
+        return Handel::Currency->new($self->_price);
+    };
+};
+
 sub total {
     my $self = shift;
-    return $self->quantity * $self->price;
+    return Handel::Currency->new($self->quantity * $self->price);
 };
 
 1;
@@ -44,10 +57,6 @@ __END__
 
 Handel::Cart::Item - Module representing an indivudal shopping cart line item
 
-=head1 VERSION
-
-    $Id: Item.pm 60 2005-01-10 02:18:33Z claco $
-
 =head1 SYNOPSIS
 
     use Handel::Cart::Item;
@@ -85,7 +94,9 @@ collection of C<Handel::Cart::Item> objects:
 
 =head1 CONSTRUCTOR
 
-You can create a new C<Handel::Cart::Item> object by call the C<new> method:
+=head2 new
+
+You can create a new C<Handel::Cart::Item> object by calling the C<new> method:
 
     my $item = Handel::Cart::Item->new({
         sku => '1234',
@@ -98,40 +109,48 @@ You can create a new C<Handel::Cart::Item> object by call the C<new> method:
     print $item->total;
 
 This is a lazy operation. No actual item record is created until the item object
-is passed into the carts C<add> method.
+is passed into the C<add> method of a C<Handel::Cart> object.
 
 =head1 METHODS
 
-=head2 C<$item-E<gt>sku>
+=head2 sku
 
 Returns or sets the sku (stock keeping unit/part number) for the cart item.
 
-=head2 C<$item-E<gt>quantity>
+=head2 quantity
 
 Returns or sets the quantity the cart item.
 
-=head2 C<$item-E<gt>price>
+=head2 price
 
 Returns or sets the price for the cart item.
 
-=head2 C<$item-E<gt>total>
+Starting in version C<0.12>, price now returns a stringified
+C<Handel::Currency> object. This can be used to format the price,
+and convert its value from on currency to another.
+
+=head2 total
 
 Returns the total price for the cart item. This is really just
 quantity*total and is provided for convenience.
 
-=head2 C<$item-E<gt>description>
+Starting in version C<0.12>, subtotal now returns a stringified
+C<Handel::Currency> object. This can be used to format the price,
+and convert its value from on currency to another.
+
+=head2 description
 
 Returns or sets the description for the cart item.
 
 =head1 SEE ALSO
 
-L<Handel::Cart>
+L<Handel::Cart>, L<Handel::Currency>
 
 =head1 AUTHOR
 
     Christopher H. Laco
     CPAN ID: CLACO
-    cpan@chrislaco.com
+    claco@chrislaco.com
     http://today.icantfocus.com/blog/
 
 
